@@ -1,12 +1,15 @@
 pub mod dump;
-pub mod extract_text;
 pub mod frontmatter;
 pub mod index;
 
+mod extract_text;
 #[allow(clippy::module_inception)]
-pub mod posts;
+mod posts;
+mod remove_comments;
 mod template;
 pub mod utils;
 
+pub use extract_text::*;
 pub use posts::*;
+pub use remove_comments::*;
 pub use template::*;
